@@ -28,21 +28,26 @@ class SSH(Target):
 
     def run(self, *arg, **kw):
         arg, kw = self.parse(*arg, **kw)
+        command = ' '.join(arg)
         check = kw.pop('check', False)
         cmd = ['ssh']
         if self.priv: cmd.extend(['-i', self.priv])
         cmd.append(f'{self.user}@{self.host}')
         cmd.append('-t')
-        cmd.extend(arg)
+        if '"' in command or "'" in command:
+            command2 = command.replace("'", r"'\''")
+            cmd.append(f"'{command2}'")
+        else:
+            cmd.extend(arg)
         kw['skip'] = self.skip
         ret, out, err =  super().run(*cmd, **kw)
-        self.trace(' '.join(arg), ret, out, err, **kw)
+        self.trace(command, ret, out, err, **kw)
         if check and ret:
-            raise ExecError(' '.join(arg), ret, out, err)
+            raise ExecError(command, ret, out, err)
         return ret, out, err
 
     def __call__(self, command, **kw):
-        ret, out, err = self.run(f'"{command}"', **kw)
+        ret, out, err = self.run(command, **kw)
         info('\n\t'.join(out))
         return ret
 
